# Native CPU names
%ifarch %{ix86}
%global nativearch x86
%else
%ifarch %{arm64}
%global nativearch arm64
%else
%global nativearch %{_arch}
%endif
%endif

# The only ELF object is hidden inside the native JAR, so turn off debuginfo
%global debug_package %{nil}

# There is a circular dependency with picocli, but this package needs
# picocli-codegen only to run tests.  Disable the tests in a bootstrap scenario.
%bcond_with bootstrap

Name:           jline
Version:        3.23.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Java library for handling console input
License:        BSD-3-Clause
URL:            https://github.com/jline/jline3
#ExclusiveArch:  %%{java_arches}

Source0:        %{url}/archive/jline-parent-%{version}.tar.gz

# Add support for ppc64le and s390x
Patch0:         %{name}-native-arches.patch
# Removed -Werror tag
Patch1:         %{name}-ignore-warnings.patch

BuildRequires:  gcc
BuildRequires:  maven-local
BuildRequires:  mvn(com.googlecode.juniversalchardet:juniversalchardet)
BuildRequires:  mvn(net.java.dev.jna:jna)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-enforcer-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.apache.sshd:sshd-core) >= 2.6.0
BuildRequires:  mvn(org.apache.sshd:sshd-scp) >= 2.6.0
BuildRequires:  mvn(org.apache.sshd:sshd-sftp) >= 2.6.0
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.easymock:easymock)
BuildRequires:  mvn(org.fusesource.jansi:jansi)

%if %{without bootstrap}
# Test dependencies
BuildRequires:  mvn(info.picocli:picocli-codegen)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apiguardian:apiguardian-api)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-params)
%endif

%global _desc %{expand:
JLine is a Java library for handling console input.  It is similar in
functionality to BSD editline and GNU readline but with additional
features that bring it in par with the ZSH line editor.  Those familiar
with the readline/editline capabilities for modern shells (such as bash
and tcsh) will find most of the command editing features of JLine to be
familiar.}

%description %_desc

%javadoc_package

%package        parent
Summary:        Parent POM for Java library for handling console input
BuildArch:      noarch

# This can be removed when F42 reaches EOL
Obsoletes:      jline < 3.23.0-1
Provides:       jline = %{version}-%{release}

%description    parent %_desc

This package contains the parent POM for the jline project

%package        native
Summary:        JLine native library

%description    native %_desc

This package contains a native library for JLine.

%package        terminal
Summary:        JLine terminal
BuildArch:      noarch
Requires:       %{name}-native = %{version}-%{release}

%description    terminal %_desc

This package contains the basic terminal support for JLine.

%package        terminal-jansi
Summary:        JLine terminal with JANSI
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    terminal-jansi %_desc

This package contains a functioning terminal based on JANSI.

%package        terminal-jna
Summary:        JLine terminal with JNA
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    terminal-jna %_desc

This package contains a functioning terminal based on JNA.

%package        reader
Summary:        JLine reader
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    reader %_desc

This package supports reading lines from a console with customizable key
bindings and input editing.

%package        style
Summary:        JLine style processor
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    style %_desc

This package contains a style processor for JLine, which can apply
colors to strings, for example.

%package        builtins
Summary:        JLine builtins
BuildArch:      noarch
Requires:       %{name}-reader = %{version}-%{release}
Requires:       %{name}-style = %{version}-%{release}
Recommends:     mvn(com.googlecode.juniversalchardet:juniversalchardet)

%description    builtins %_desc

This package contains keybindings to emulate popular tools such as nano
and less.

%package        console
Summary:        JLine console
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Requires:       %{name}-style = %{version}-%{release}

%description    console %_desc

This package contains a console with command and script execution
support, and tab completion.

%package        remote-ssh
Summary:        JLine remote SSH
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Recommends:     mvn(org.apache.sshd:sshd-core) >= 2.6.0
Recommends:     mvn(org.apache.sshd:sshd-scp) >= 2.6.0
Recommends:     mvn(org.apache.sshd:sshd-sftp) >= 2.6.0

%description    remote-ssh %_desc

This package contains an ssh client.

%package        remote-telnet
Summary:        JLine remote telnet
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Recommends:     mvn(org.apache.sshd:sshd-core) >= 2.6.0

%description    remote-telnet %_desc

This package contains a telnet client.

%prep
%autosetup -n jline3-jline-parent-%{version} -p1

# remove unnecessary dependency on parent POM
%pom_remove_parent

# We don't need the bundle
%pom_disable_module jline

# Missing dependencies in Fedora
%pom_disable_module demo
%pom_disable_module groovy
%pom_disable_module graal
%pom_remove_plugin :gmavenplus-plugin
%pom_remove_dep :graal-sdk

# Unnecessary plugins for an rpm build
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-release-plugin
%pom_remove_plugin :native-image-maven-plugin
%pom_remove_plugin :spotless-maven-plugin

%if %{with bootstrap}
# In a bootstrap situation, do not try to run picocli-codegen
%pom_remove_plugin :exec-maven-plugin native
%endif

# junit-jupiter needs apiguardian-api but doesn't depend on it
%pom_add_dep org.apiguardian:apiguardian-api:1.1.2:test native

# Bump the JNI version up to the minimum supported by Fedora
sed -i 's/\(JNI_VERSION_1_\)2/\18/' native/src/main/native/jlinenative.c

# Remove prebuilt native objects
rm -fr native/src/main/resources/org/jline/nativ/{FreeBSD,Mac,Windows}
rm -fr native/src/main/resources/org/jline/nativ/Linux/*

%build
# Build a native object
mkdir native/src/main/resources/org/jline/nativ/Linux/%{nativearch}
cd native/src/main/native
gcc %{build_cflags} -fPIC -fvisibility=hidden -shared -I. \
  -I %{_jvmdir}/java/include -I %{_jvmdir}/java/include/linux %{build_ldflags} \
  -o ../resources/org/jline/nativ/Linux/%{nativearch}/libjlinenative.so \
  jlinenative.c
cd -

# Build the Java artifacts
%if %{with bootstrap}
%mvn_build -f -s
%else
%mvn_build -s
%endif

%install
%mvn_install

%files parent -f .mfiles-jline-parent
%doc changelog.md README.md
%license LICENSE.txt

%files native -f .mfiles-jline-native
%doc changelog.md README.md
%license LICENSE.txt

%files terminal -f .mfiles-jline-terminal

%files terminal-jansi -f .mfiles-jline-terminal-jansi

%files terminal-jna -f .mfiles-jline-terminal-jna

%files reader -f .mfiles-jline-reader

%files style -f .mfiles-jline-style

%files builtins -f .mfiles-jline-builtins

%files console -f .mfiles-jline-console

%files remote-ssh -f .mfiles-jline-remote-ssh

%files remote-telnet -f .mfiles-jline-remote-telnet




%changelog
* Sat May 25 2024 daviddavid <daviddavid> 3.23.0-2.mga10
+ Revision: 2067495
- add patch to remove '-Werror' build flag
+ ns80 <ns80>
- rebuild for java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 3.23.0-1.mga10
+ Revision: 1986709
- Version 3.23.0
- Add native subpackage
- Move parent POM to a parent subpackage
- Drop upstreamed -apache-sshd patch

* Fri Dec 09 2022 daviddavid <daviddavid> 3.21.0-1.mga9
+ Revision: 1919718
- Version 3.21.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Mar 21 2021 daviddavid <daviddavid> 3.19.0-1.mga9
+ Revision: 1706555
- new version: 3.19.0

* Fri Mar 12 2021 daviddavid <daviddavid> 3.18.0-2.mga9
+ Revision: 1701786
- Fix build against apache-sshd 2.6.0

* Sun Feb 28 2021 daviddavid <daviddavid> 3.18.0-1.mga9
+ Revision: 1694474
- Version 3.18.0
- Remove package name from Summary
- Add patch to adapt to recent versions of apache-sshd
- Break up into subpackages to control dependencies

* Mon Sep 07 2020 daviddavid <daviddavid> 2.14.6-4.mga9
+ Revision: 1623133
- Drop useless parent POM and powermock build dependencies
- Rebuilt for JDK-11
- Fix Java 11 build

* Wed Feb 12 2020 umeabot <umeabot> 2.14.6-3.mga8
+ Revision: 1501845
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 2.14.6-2.mga7
+ Revision: 1278994
- Mageia 7 Mass Rebuild

* Thu May 24 2018 daviddavid <daviddavid> 2.14.6-1.mga7
+ Revision: 1232049
- Update to upstream version 2.14.6 (sync with fc29)

* Sat Jun 25 2016 daviddavid <daviddavid> 2.13-4.mga6
+ Revision: 1037477
- Remove nondeterministic test
- Regenerate build-requires
- OSGi export jline.internal. Resolves RHBZ#1317551
+ neoclust <neoclust>
- Second rebuild of the java stack

* Thu Feb 25 2016 daviddavid <daviddavid> 2.13-3.mga6
+ Revision: 978875
- rebuild to regenerate Provides list

* Tue Feb 23 2016 neoclust <neoclust> 2.13-2.mga6
+ Revision: 977109
- First rebuild of the java stack
- sync package jline with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 luigiwalser <luigiwalser> 2.10-5.mga5
+ Revision: 805915
- bump release to properly obsolete jline2

* Wed Oct 15 2014 umeabot <umeabot> 2.10-3.mga5
+ Revision: 746554
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 dmorgan <dmorgan> 2.10-1.mga5
+ Revision: 636423
- New version

* Tue Oct 22 2013 umeabot <umeabot> 1.0-2.mga4
+ Revision: 545448
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 1.0-1.mga4
+ Revision: 501278
- New version

* Wed Jan 16 2013 dmorgan <dmorgan> 0.9.94-5.mga3
+ Revision: 388706
- Revert to version 0.9.94
- New version 1.0
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Apr 28 2011 dmorgan <dmorgan> 0.9.94-4.mga1
+ Revision: 92542
- Rebuild after bootstrapping
- imported package jline


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.94-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Dec 18 2010 Mat Booth <fedora@matbooth.co.uk> - 0.9.94-2
- Remove pre-built Windows-only binary artifacts.
- Demo package was defined but never built for some reason.
- Don't also package jar in the javadoc package!
- Drop versioned java and javadocs.

* Sat Dec 18 2010 Mat Booth <fedora@matbooth.co.uk> - 0.9.94-1
- Remove bundled jars in %%prep phase.
- Tidy up spec file, fix some rpmlint warnings.
- Add pom and depmaps.

* Mon Mar  8 2010 Peter Lemenkov <lemenkov@gmail.com> - 0:0.9.94-0.6
- Added missing Requires: jpackage-utils (%%{_javadir} and %%{_javadocdir})

* Tue Jan 12 2010 Alexander Kurtakov <akurtako@redhat.com> 0:0.9.94-0.5
- Fix BRs.
- Drop gcj_support.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:0.9.94-0.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:0.9.94-0.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul  9 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0:9.94-0.2
- drop repotag

* Mon Mar 24 2008 Matt Wringe <mwringe@redhat.com> - 0:9.94-0jpp.1
- Update to 0.9.94 (BZ #436204)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0:0.9.9-2jpp.1
- Autorebuild for GCC 4.3

* Tue Mar 06 2007 Matt Wringe <mwringe@redhat.com> - 0:0.9.9-1jpp.1
- Add option to build with ant.
- Fix various rpmlint issues
- Specify proper license

* Thu May 04 2006 Alexander Kurtakov <akurtkov at gmail.com> - 0:0.9.9-1jpp
- Upgrade to 0.9.9

* Thu May 04 2006 Ralph Apel <r.apel at r-apel.de> - 0:0.9.5-1jpp
- Upgrade to 0.9.5
- First JPP-1.7 release

* Mon Apr 25 2005 Fernando Nasser <fnasser@redhat.com> - 0:0.9.1-1jpp
- Upgrade to 0.9.1
- Disable attempt to include external jars

* Mon Apr 25 2005 Fernando Nasser <fnasser@redhat.com> - 0:0.8.1-3jpp
- Changes to use locally installed DTDs
- Do not try and access sun site for linking javadoc

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:0.8.1-2jpp
- Rebuild with ant-1.6.2

* Mon Jan 26 2004 David Walluck <david@anti-microsoft.org> 0:0.8.1-1jpp
- release
